@@ -13,7 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-""" Kafka consumer to listen and archive Fink streams """
+""" Kafka consumer to listen and archive Fink streams from the Livestream service """
 import sys
 
 import argparse
